package cn.estsh.i3plus.ext.mes.pcn.apiservice.controller.busi;


import cn.estsh.i3plus.ext.mes.pcn.api.busi.IMesNcProcessingService;
import cn.estsh.i3plus.ext.mes.pcn.pojo.constant.MesCommonConstant;
import cn.estsh.i3plus.ext.mes.pcn.pojo.model.MesNcProcessingInputModel;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.mes.bean.nc.MesPartInspection;
import cn.estsh.i3plus.pojo.mes.util.MesExtEnumUtil;
import cn.estsh.impp.framework.boot.auth.AuthUtil;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

@RestController
@Api(tags = "NC处理页面")
@RequestMapping(MesCommonConstant.MES_YANFEN + "/nc-processing")
@Slf4j
public class MesNcProcessingController {

    @Autowired
    private IMesNcProcessingService ncProcessingService;


    @GetMapping("/query-part-inspection-pager")
    @ApiOperation(value = "查询NC-零件检测-单据")
    public ResultBean queryPartInspectionByPager(MesPartInspection partInspection, Pager pager) {

        try {

            partInspection.setOrganizeCode(AuthUtil.getOrganizeCode());
            ListPager<MesPartInspection> partInspectionListPager = ncProcessingService.queryPartInspectionByPager(partInspection, pager);
            return ResultBean.success("查询成功").setListPager(partInspectionListPager);
        } catch (ImppBusiException imppException) {
            return ResultBean.fail(imppException);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @GetMapping("/query-part-inspection")
    @ApiOperation(value = "查询NC-零件检测-单据")
    public ResultBean queryPartInspection(MesPartInspection partInspection) {

        try {

            partInspection.setOrganizeCode(AuthUtil.getOrganizeCode());
            return ResultBean.success("查询成功").setResultObject(ncProcessingService.queryPartInspection(partInspection));
        } catch (ImppBusiException imppException) {
            return ResultBean.fail(imppException);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @GetMapping("/query-person")
    @ApiOperation(value = "查询责任人")
    public ResultBean queryPerson() {

        try {

            return ResultBean.success("查询成功").setResultList(ncProcessingService.queryPerson(AuthUtil.getOrganizeCode()));
        } catch (ImppBusiException imppException) {
            return ResultBean.fail(imppException);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }


    @PostMapping("/save-nc")
    @ApiOperation(value = "NC处理")
    public ResultBean saveNc(@RequestBody MesNcProcessingInputModel model) {

        try {
            // 数据校验
            ValidatorBean.checkNotNull(model.getPartInspection(), "单据不能为空");
            ValidatorBean.checkNotNull(model.getPartInspectionDetailList(), "单据明细不能为空");
            if (model.getType() != 10) {
                ValidatorBean.checkNotNull(model.getPerson(), "责任人不能为空");
            }

            String description = MesExtEnumUtil.NC_TYPE.valueOfDescription(model.getType());
            if (StringUtils.isEmpty(description)) {
                throw new ImppBusiException(String.format("【%s】类型不存在，请检查数据", model.getType()));

            }
            if (CollectionUtils.isEmpty(model.getPartInspectionDetailList())) {
                throw new ImppBusiException(String.format("不存在可疑信息，请检查数据", model.getType()));
            }
            ncProcessingService.saveNc(model, AuthUtil.getOrganizeCode());
            return ResultBean.success("NC处理成功");
        } catch (ImppBusiException imppException) {
            return ResultBean.fail(imppException);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

}
